import { Injectable } from '@nestjs/common';
import {
  db,
  Prisma,
  UserProfile,
  VisitType,
  Post,
  PostType,
  RolePerms,
  ResPerm,
  ObjectType,
  CourseMethodSchema,
} from '@nice/common';
import { MessageService } from '../message/message.service';
import { BaseService } from '../base/base.service';
import { DepartmentService } from '../department/department.service';
import EventBus, { CrudOperation } from '@server/utils/event-bus';
import { BaseTreeService } from '../base/base.tree.service';
import { z } from 'zod';
@Injectable()
export class DriverService extends BaseTreeService<Prisma.DriverDelegate> {
  constructor(
    private readonly messageService: MessageService,
    private readonly departmentService: DepartmentService,
  ) {
    super(db, ObjectType.DRIVER, 'driverAncestry', true);
  }
  async create(
    args: Prisma.DriverCreateArgs,
    params?: { staff?: UserProfile; tx?: Prisma.TransactionClient },
  ) {
    const result = await db.driver.create(args);
    EventBus.emit('dataChanged', {
      type: ObjectType.DRIVER,
      operation: CrudOperation.CREATED,
      data: result,
    });
    return result;
  }
  async update(args: Prisma.DriverUpdateArgs, staff?: UserProfile) {
    const result = await db.driver.update(args);
    EventBus.emit('dataChanged', {
      type: ObjectType.DRIVER,
      operation: CrudOperation.UPDATED,
      data: result,
    });
    return result;
  }
    /**
   * 查找赛车并包含比赛信息
   */
    async findWithScores(clubId: number) {
      return await db.driver.findUnique({
        where: { id: clubId },
        select: {
          name:true,
          club:true
        }
      });
    }
      /**
   * 搜索学生
   */
  async search(params: { name?: string, clubId?: number, limit?: number }) {
    const { name, clubId, limit = 30 } = params;
    
    return await db.driver.findMany({
      where: {
        ...(name && { name: { contains: name } }),
        ...(clubId && { clubId })
      },
      select: {
        clubId: true,
        name:true
      },
      take: limit
    });
  }
  private emitDataChangedEvent(data: any, operation: CrudOperation) {
    EventBus.emit("dataChanged", {
      type: this.objectType,
      operation,
      data,
    });
  }
}
