import React, { useState, useEffect } from 'react';

const ScoreForm = ({ onSubmit, editingScore = null, students, courses }) => {
  const [formData, setFormData] = useState({
    studentId: '',
    courseId: '',
    score: '',
    semester: ''
  });
    const [students1, setStudents1] = useState([]);
    const [courses1, setCourses1] = useState([]);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    // 如果是编辑模式，使用editingScore填充表单
    if (editingScore) {
      setFormData({
        studentId: editingScore.studentId,
        courseId: editingScore.courseId,
        score: editingScore.score,
        semester: editingScore.semester
      });
    } 
    fetchStudentsAndCourses();
  }, [editingScore]);

  const fetchStudentsAndCourses = async () => {
    setLoading(true);
    try {
      // 模拟API调用
      setTimeout(() => {
        setStudents1(students);
        setCourses1(courses);
        setLoading(false);
      }, 500);
    } catch (error) {
      console.error('获取数据失败', error);
      setLoading(false);
    }
  };

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: name === 'score' ? parseFloat(value) : value
    });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    onSubmit(formData);
    // 重置表单
    if (!editingScore) {
      setFormData({
        studentId: '',
        courseId: '',
        score: '',
        semester: ''
      });
    }
  };

  return (
    <div className="bg-white p-6 rounded-lg shadow mb-6">
      <h2 className="text-xl font-semibold mb-4">{editingScore ? '编辑成绩' : '添加成绩'}</h2>
      {loading ? (
        <div className="text-center py-4">加载中...</div>
      ) : (
        <form onSubmit={handleSubmit}>
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
            <div>
              <label className="block text-sm font-medium text-gray-700 mb-1">学生</label>
              <select
                name="studentId"
                value={formData.studentId}
                onChange={handleChange}
                className="w-full px-3 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              >
                <option value="">选择学生</option>
                {students.map(student => (
                  <option key={student.id} value={student.id}>
                    {student.name}
                  </option>
                ))}
              </select>
            </div>
            
            <div>
              <label className="block text-sm font-medium text-gray-700 mb-1">课程</label>
              <select
                name="courseId"
                value={formData.courseId}
                onChange={handleChange}
                className="w-full px-3 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              >
                <option value="">选择课程</option>
                {courses.map(course => (
                  <option key={course.id} value={course.id}>
                    {course.name}
                  </option>
                ))}
              </select>
            </div>
            
            <div>
              <label className="block text-sm font-medium text-gray-700 mb-1">分数</label>
              <input
                type="number"
                name="score"
                value={formData.score}
                onChange={handleChange}
                placeholder="输入分数"
                min="0"
                max="100"
                step="0.1"
                className="w-full px-3 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              />
            </div>
            
            <div>
              <label className="block text-sm font-medium text-gray-700 mb-1">学期</label>
              <select
                name="semester"
                value={formData.semester}
                onChange={handleChange}
                className="w-full px-3 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                required
              >
                <option value="">选择学期</option>
                <option value="2023-春季">2023-春季</option>
                <option value="2023-秋季">2023-秋季</option>
                <option value="2024-春季">2024-春季</option>
              </select>
            </div>
          </div>
          
          <div className="flex justify-end">
            <button
              type="submit"
              className="bg-blue-500 hover:bg-blue-600 text-white font-medium py-2 px-6 rounded-md transition duration-200"
            >
              {editingScore ? '更新成绩' : '添加成绩'}
            </button>
          </div>
        </form>
      )}
    </div>
  );
};

export default ScoreForm;