import React from 'react';
import Pagination from './Pagination';
const ScoreTable = ({ scores, students, courses, currentPage, totalPages, onPageChange, onEdit, onDelete }) => {
  // 获取学生和课程名称的辅助函数
  const getStudentName = (studentId) => {
    if (!students || !Array.isArray(students)) return '未知学生';
    if (studentId === undefined || studentId === null) return '未知学生';
    
    const student = students.find(s => s.id === studentId);
    return student && student.name ? student.name : '未知学生';
  };
  const getCourseName = (courseId) => {
    if (!courses || !Array.isArray(courses)) return '未知课程';
    if (courseId === undefined || courseId === null) return '未知课程';
    
    const course = courses.find(c => c.id === courseId);
    return course && course.name ? course.name : '未知课程';
  };
  


  return (
    <div className="bg-white rounded-lg shadow overflow-hidden">
      <h2 className="text-xl font-semibold p-4 border-b">成绩列表</h2>
      <div className="overflow-x-auto">
        <table className="min-w-full divide-y divide-gray-200">
          <thead className="bg-gray-50">
            <tr>
              <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">
                学生姓名
              </th>
              <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">
                课程
              </th>
              <th className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">
                分数
              </th>
              <th className="px-6 py-3 text-right text-xs font-medium text-gray-500 uppercase tracking-wider">
                操作
              </th>
            </tr>
          </thead>
          <tbody className="bg-white divide-y divide-gray-200">
            {scores.length > 0 ? (
              scores.map((score) => (
                <tr key={score.id} className="hover:bg-gray-50">
                  <td className="px-6 py-4 whitespace-nowrap">
                    {getStudentName(score.studentId)}
                  </td>
                  <td className="px-6 py-4 whitespace-nowrap">
                    {getCourseName(score.courseId)}
                  </td>
                  <td className="px-6 py-4 whitespace-nowrap">
                    <span className={`px-2 py-1 rounded-full text-sm ${
                      score.score >= 90 ? 'bg-green-100 text-green-800' :
                      score.score >= 60 ? 'bg-blue-100 text-blue-800' :
                      'bg-red-100 text-red-800'
                    }`}>
                      {score.score}
                    </span>
                  </td>
                  <td className="px-6 py-4 whitespace-nowrap text-right text-sm font-medium">
                    <button
                      onClick={() => onEdit(score)}
                      className="text-indigo-600 hover:text-indigo-900 mr-4"
                    >
                      编辑
                    </button>
                    <button
                      onClick={() => onDelete(score.id)}
                      className="text-red-600 hover:text-red-900"
                    >
                      删除
                    </button>
                  </td>
                </tr>
              ))
            ) : (
              <tr>
                <td colSpan={5} className="px-6 py-4 text-center text-gray-500">
                  没有找到成绩记录
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
      
      {scores.length > 0 && (
        <div className="px-4 py-3 border-t border-gray-200">
          <Pagination 
            currentPage={currentPage} 
            totalPages={totalPages} 
            onPageChange={onPageChange} 
          />
        </div>
      )}
    </div>
  );
};

export default ScoreTable;