import React, { useState } from 'react';

const StudentSearch = ({ onSearch }) => {
  const [searchTerm, setSearchTerm] = useState('');
  const [searchType, setSearchType] = useState('name'); // 'name', 'class', 'course'

  const handleSearch = () => {
    onSearch(searchTerm, searchType);
  };

  return (
    <div className="bg-white p-4 rounded-lg shadow mb-6">
      <h2 className="text-xl font-semibold mb-4">学生搜索</h2>
      <div className="flex flex-col md:flex-row gap-4">
        <div className="flex-1">
          <input
            type="text"
            placeholder="输入搜索关键词..."
            className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
            value={searchTerm}
            onChange={(e) => setSearchTerm(e.target.value)}
          />
        </div>
        <div className="w-full md:w-48">
          <select
            className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
            value={searchType}
            onChange={(e) => setSearchType(e.target.value)}
          >
            <option value="name">按学生姓名</option>
            <option value="class">按班级</option>
            <option value="course">按课程</option>
          </select>
        </div>
        <button
          className="bg-blue-500 hover:bg-blue-600 text-white font-medium py-2 px-6 rounded-md transition duration-200"
          onClick={handleSearch}
        >
          搜索
        </button>
      </div>
    </div>
  );
};

export default StudentSearch;