import React from 'react';
import { Outlet, Link, useLocation } from 'react-router-dom';

const MainLayout: React.FC = () => {
    const location = useLocation();
    const pathnames = location.pathname.split('/').filter((x) => x);

    return (
        <div className="min-h-screen flex">
            {/* 侧边栏 */}
            <div className="w-64 bg-gray-800 text-white p-4">
                <nav className="space-y-2">
                    <Link 
                        to="/" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        学生管理
                    </Link>
                    <Link 
                        to="/car" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        车辆管理
                    </Link>
                    <Link 
                        to="/club" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        俱乐部管理
                    </Link>
                    <Link 
                        to="/driver" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        车手管理
                    </Link>
                    <Link 
                        to="/game" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        比赛管理
                    </Link>
                    <Link 
                        to="/sortie" 
                        className="block px-4 py-2 text-sm font-medium rounded-md hover:bg-gray-700 transition-colors"
                    >
                        车次管理
                    </Link>
                </nav>
            </div>
            {/* 主内容区域 */}
            <div className="flex-1 flex flex-col">
                {/* 顶部导航栏 */}
                <div className="bg-blue-600 text-white p-4">
                    <div className="flex items-center space-x-2">
                        <Link to="/" className="hover:text-gray-200">
                            首页
                        </Link>
                        {pathnames.map((value, index) => {
                            const to = `/${pathnames.slice(0, index + 1).join('/')}`;
                            const isLast = index === pathnames.length - 1;
                            return isLast ? (
                                <span key={to} className="font-medium">
                                    / {value}
                                </span>
                            ) : (
                                <Link key={to} to={to} className="hover:text-gray-200">
                                    / {value}
                                </Link>
                            );
                        })}
                    </div>
                </div>
                {/* 主要内容 */}
                <div className="flex-1 p-4">
                    <Outlet />
                </div>
                {/* 底部 */}
                <div className="bg-gray-800 text-white p-4">
                    Footer
                </div>
            </div>
        </div>
    );
};

export default MainLayout;