'use client';
import { api } from '@nice/client';
import { useEffect, useState } from 'react';
import { Modal, Form, Input, Button } from 'antd';
const StudentTestPage = () => {
    const [studentName, setStudentName] = useState('');
    const [data, setdata] = useState([])
    const [editStudentId, setEditStudentId] = useState<number | null>(null);
    const [editStudentName, setEditStudentName] = useState('');
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [searchTerm, setSearchTerm] = useState('');

    const {
        data: students = [],
        isLoading,
        error,
        refetch
    } = api.student.findMany.useQuery({
        select: {
            id: true,
            name: true,
        }
    });
    // setdata(students)
    console.log('students', students);
    useEffect(() => {
        setdata(students)
    }, [students])
    const filteredStudents = students.filter(student => 
        student.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
        student.id.toString().includes(searchTerm)

    );
    // const  {data:students, isLoading, error} = api.student.findMany.useQuery({
    //     where: {
    //         id: 1
    //     },
    //     select: {
    //         name: true,
    //         id: true,
    //     }
    // });
    // console.log('students', students);

    // const {data:courses, isLoading, error} = api.course.findMany.useQuery({
    //     select: {
    //         id: true,
    //         name: true,
    //         scores: true,
    //     }
    // });
    // console.log('courses',courses);

    // const {data:scores, isLoading, error} = api.score.findMany.useQuery({
    //     select: {
    //         id: true,
    //         studentId: true,
    //         courseId: true,
    //         score: true,
    //     }
    // });
    // console.log('scores',scores);

    // const handleAddStudent = api.student.create.useMutation({
    //     onSuccess: () => {
    //         console.log('添加学生成功');
    //     },
    //     onError: (error) => {
    //         console.log('添加分数失败', error);
    //     }
    // })
    // handleAddStudent.mutate({
    //     data: {
    //         name: '张三',
    //         classId: 10,
    //     }
    // })

    const deleteStudentMutation = api.student.delete.useMutation({
        onSuccess: () => {
            console.log('删除成功');
            refetch()
        },
        onError: (error) => {
            console.error('删除失败:', error);
        }
    });
    const handleDeleteStudent = (studentId: number) => {
        deleteStudentMutation.mutateAsync({ id: studentId });
    };
    const editStudentMutation = api.student.update.useMutation({
        onSuccess: () => {
            console.log('编辑成功');
            refetch()
        },
        onError: (error) => {
            console.error('编辑失败:', error);
            alert(`编辑失败: ${error.message}`);
        }
    });
    const handleEditStudent = (studentId?: number, name?: string) => {
        if (studentId ) { 
            const studentIdNumber = Number(studentId);
            editStudentMutation.mutate({ where: { id: studentIdNumber }, data: { name: name } });
            setEditStudentId(studentIdNumber);
            setEditStudentName(name);
            setIsModalOpen(true);
            refetch()
        }
    };
    const handleOk = (studentId?: number, name?: string) => {
        if (studentId && editStudentName) {
            const studentIdNumber = Number(editStudentId);
            editStudentMutation.mutate({
                where: { id: editStudentId },
                data: { name: editStudentName }
            });
        }
        setIsModalOpen(false);
        setEditStudentId(null);
        setEditStudentName('');
        refetch()
    };
    const handleCancel = () => {
        setIsModalOpen(false);
        refetch()
    };

    // 增加
    const addStudentMutation = api.student.create.useMutation({
        onSuccess: (data) => {
            console.log('添加成功:', data);
            setStudentName(''); // 清空输入
            // 刷新列表
            refetch()
        },
        onError: (error) => {
            console.error('添加失败:', error);
            alert(`添加失败: ${error.message}`);
        }
    });
    const handleAddStudent = () => {

        // 正确构造Prisma创建参数
        addStudentMutation.mutateAsync({
            data: {
                name: studentName
            }
        });
    };


    return (
        <div className="p-5">
            <h1 className="text-xl font-bold mb-4">API测试</h1>
                   {/* 添加搜索框 */}
                   <div className="mb-4">
                <Input.Search
                    placeholder="搜索学生姓名或ID"
                    allowClear
                    enterButton
                    value={searchTerm}
                    onChange={(e) => setSearchTerm(e.target.value)}
                    onSearch={setSearchTerm}
                    className="max-w-md"
                />
            </div>
            <div className="mb-4">
                <input
                type="text"
                value={studentName}
                onChange={(e) => setStudentName(e.target.value)}
                placeholder="学生姓名"
                className="border rounded px-3 py-2 flex-1"
            />
            <button onClick={() => handleAddStudent()} className='bg-blue-500 text-white px-3 py-1 rounded-md hover:bg-blue-600'>添加</button>
            </div>
            
            {isLoading && <div>加载中...</div>}
            
            {/* 使用过滤后的学生列表 */}
            {filteredStudents.length > 0 ? (
                filteredStudents.map((student) => (
                    <div key={student.id} className="mb-3 p-3 border rounded flex justify-between items-center">
                        <div>
                            <p className="font-medium">ID: {student.id}</p>
                            <p>姓名: {student.name}</p>
                        </div>
                        <div className="flex gap-2">
                            <button onClick={() => handleEditStudent(student.id, student.name)} 
                                    className='bg-blue-500 text-white px-3 py-1 rounded-md hover:bg-blue-600'>
                                编辑
                            </button>
                            <button onClick={() => handleDeleteStudent(student.id)} 
                                    className='bg-red-500 text-white px-3 py-1 rounded-md hover:bg-red-600'>
                                删除
                            </button>
                        </div>
                    </div>
                ))
            ) : (
                <div className="text-gray-500 my-4">未找到匹配的学生</div>
            )}
            {/* {isLoading && <div className="text-gray-600">加载中...</div>}
            {error && (
                <div className="bg-red-100 border-l-4 border-red-500 p-4 mb-5">
                    <p className="font-bold">错误</p>
                    <p>{error.message}</p>
                </div>
            )}
            {!isLoading && !error && (
                <div>
                    <p className="mb-2">成功获取 {scores.length} 分数:</p>
                    <pre className="bg-gray-100 p-4 rounded overflow-auto max-h-96">
                        {JSON.stringify(scores, null, 2)}
                    </pre>
                </div>
            )} */}
            {/* {isLoading && <div>加载中...</div>}
            {students && students.length > 0 &&
                students.map((student) => (
                    <div key={student.id}>
                        <p>ID: {student.id}</p>
                        <p>姓名: {student.name}</p>
                        <button onClick={() => handleDeleteStudent(student.id)} className='bg-red-500 text-white px-4 py-2 rounded-md'>删除</button>
                        <div>
                            <button onClick={() => handleEditStudent(student.id,student.name)} className='bg-blue-500 text-white px-4 py-2 rounded-md'>编辑</button>
                        </div>
                    </div>
                ))
            } */}

            <Modal
                title="编辑学生"
                open={isModalOpen}
                onOk={() => handleOk(editStudentId, editStudentName)}
                onCancel={handleCancel}
            >
                <Input
                    value={editStudentName}
                    onChange={(e) => setEditStudentName(e.target.value)}
                    placeholder="输入学生姓名"
                />
            </Modal>

        </div>
    );
    
};

export default StudentTestPage;